# **Inferencia probabilistica**
**libreria simple de python para crear redes bayesianas y realizar consultas**<br>

### Instalacion
pip install bayesnetwork

### Uso
crear nodos con bayesnode y alimentarlos a la red bayes tal como el archivo test.py


 
